=======
History
=======

1.1.0 (2020-12-13)
------------------

* Drop Python 3.5 support.
* Support Python 3.9.
* Move license from ISC to MIT License.

1.0.0 (2019-11-19)
------------------

* First release on PyPI.
* ``NT001`` rule that complains about type annotations.
